==> mars-sdk-3.0.0.1-sources.jar: com/bizunited/nebula/mars/sdk/vo/SelectAuthorityModeRegisterVo.java <==
package com.bizunited.nebula.mars.sdk.vo;

/**
 * 该vo模型负责描述进行查询时，从服务层返回的数据权限项信息</p>
 * 详细清晰查询 {@link #SelectAuthorityModeRegister()}的描述，这里不再赘述
 * @author yinwenjie
 */
public class SelectAuthorityModeRegisterVo {
  private String modeKey;
  private String modeName;
  private String controlKey;
  private int sort;
  private String groupCode;
  private Boolean arrayValue;
  private Boolean staticValue;
  /**
   * 注意，由于类型值需要进行网络传输，所以不能传递class，只能传递class的文字表达
   */
  private String modeValueClass;
  /**
   * 通过SelectAuthorityModeRegister转换得到的该数据项的最终值</p>
   * 请注意，该值一定需要支持序列化，否则远程调用会出问题
   */
  private Object modeValue;
  /**
   * 转换器的key信息
   */
  private String converterKey;
  
  public String getModeKey() {
    return modeKey;
  }
  public void setModeKey(String modeKey) {
    this.modeKey = modeKey;
  }
  public String getModeName() {
    return modeName;
  }
  public void setModeName(String modeName) {
    this.modeName = modeName;
  }
  public String getControlKey() {
    return controlKey;
  }
  public void setControlKey(String controlKey) {
    this.controlKey = controlKey;
  }
  public int getSort() {
    return sort;
  }
  public void setSort(int sort) {
    this.sort = sort;
  }
  public Boolean getArrayValue() {
    return arrayValue;
  }
  public void setArrayValue(Boolean arrayValue) {
    this.arrayValue = arrayValue;
  }
  public Boolean getStaticValue() {
    return staticValue;
  }
  public void setStaticValue(Boolean staticValue) {
    this.staticValue = staticValue;
  }
  public String getModeValueClass() {
    return modeValueClass;
  }
  public void setModeValueClass(String modeValueClass) {
    this.modeValueClass = modeValueClass;
  }
  public String getGroupCode() {
    return groupCode;
  }
  public void setGroupCode(String groupCode) {
    this.groupCode = groupCode;
  }
  public String getConverterKey() {
    return converterKey;
  }
  public void setConverterKey(String converterKey) {
    this.converterKey = converterKey;
  }
  public Object getModeValue() {
    return modeValue;
  }
  public void setModeValue(Object modeValue) {
    this.modeValue = modeValue;
  }
}

==> mars-sdk-24.07.09-sources.jar: com/bizunited/nebula/mars/sdk/vo/SelectAuthorityModeRegisterVo.java <==
package com.bizunited.nebula.mars.sdk.vo;

/**
 * 该vo模型负责描述进行查询时，从服务层返回的数据权限项信息</p>
 * 详细清晰查询 {@link #SelectAuthorityModeRegister()}的描述，这里不再赘述
 * @author yinwenjie
 */
public class SelectAuthorityModeRegisterVo {
  private String modeKey;
  private String modeName;
  private String controlKey;
  private int sort;
  private String groupCode;
  private Boolean arrayValue;
  private Boolean staticValue;
  /**
   * 注意，由于类型值需要进行网络传输，所以不能传递class，只能传递class的文字表达
   */
  private String modeValueClass;
  /**
   * 通过SelectAuthorityModeRegister转换得到的该数据项的最终值</p>
   * 请注意，该值一定需要支持序列化，否则远程调用会出问题
   */
  private Object modeValue;
  /**
   * 转换器的key信息
   */
  private String converterKey;
  /**
   * 转换之后的数据项
   */
  private Object converterModeValue;
  
  public String getModeKey() {
    return modeKey;
  }
  public void setModeKey(String modeKey) {
    this.modeKey = modeKey;
  }
  public String getModeName() {
    return modeName;
  }
  public void setModeName(String modeName) {
    this.modeName = modeName;
  }
  public String getControlKey() {
    return controlKey;
  }
  public void setControlKey(String controlKey) {
    this.controlKey = controlKey;
  }
  public int getSort() {
    return sort;
  }
  public void setSort(int sort) {
    this.sort = sort;
  }
  public Boolean getArrayValue() {
    return arrayValue;
  }
  public void setArrayValue(Boolean arrayValue) {
    this.arrayValue = arrayValue;
  }
  public Boolean getStaticValue() {
    return staticValue;
  }
  public void setStaticValue(Boolean staticValue) {
    this.staticValue = staticValue;
  }
  public String getModeValueClass() {
    return modeValueClass;
  }
  public void setModeValueClass(String modeValueClass) {
    this.modeValueClass = modeValueClass;
  }
  public String getGroupCode() {
    return groupCode;
  }
  public void setGroupCode(String groupCode) {
    this.groupCode = groupCode;
  }
  public String getConverterKey() {
    return converterKey;
  }
  public void setConverterKey(String converterKey) {
    this.converterKey = converterKey;
  }
  public Object getModeValue() {
    return modeValue;
  }
  public void setModeValue(Object modeValue) {
    this.modeValue = modeValue;
  }

  public Object getConverterModeValue() {
    return converterModeValue;
  }

  public void setConverterModeValue(Object converterModeValue) {
    this.converterModeValue = converterModeValue;
  }
}
